@@ -117,6 +117,14 @@ dt_boxhead_set_hidden <- function(data, vars) {
   dt_boxhead %>% dt_boxhead_set(data = data)
 }
 
+dt_boxhead_set_not_hidden <- function(data, vars) {
+
+  dt_boxhead <- dt_boxhead_get(data = data)
+
+  dt_boxhead[which(dt_boxhead$var %in% vars), "type"] <- "default"
+  dt_boxhead %>% dt_boxhead_set(data = data)
+}
+
 dt_boxhead_set_stub <- function(data, var) {
 
   dt_boxhead <- dt_boxhead_get(data = data)
@@ -137,51 +145,58 @@ dt_boxhead_set_row_group <- function(data, vars) {
 
 dt_boxhead_edit_column_label <- function(data, var, column_label) {
 
-  dt_boxhead_edit(data, var, column_label = column_label)
+  dt_boxhead_edit(
+    data = data,
+    var = var,
+    column_label = column_label
+  )
 }
 
 dt_boxhead_get_vars <- function(data) {
 
-  data %>%
-    dt_boxhead_get() %>%
-    magrittr::extract2("var")
+  dplyr::pull(dt_boxhead_get(data = data), var)
 }
 
 dt_boxhead_get_vars_default <- function(data) {
 
-  data %>%
-    dt_boxhead_get() %>%
-    dplyr::filter(type == "default") %>%
-    magrittr::extract2("var")
+  dplyr::pull(subset(dt_boxhead_get(data = data), type == "default"), var)
 }
 
 dt_boxhead_get_var_stub <- function(data) {
-  res <- dt_boxhead_get_var_by_type(data, "stub")
-  if (length(res) == 0)
+
+  res <- dt_boxhead_get_var_by_type(data = data, "stub")
+
+  if (length(res) == 0) {
     NA_character_
-  else
+  } else {
     res
+  }
 }
 
 dt_boxhead_get_vars_groups <- function(data) {
-  dt_boxhead_get_var_by_type(data, "row_group")
+  dt_boxhead_get_var_by_type(data = data, "row_group")
 }
 
 dt_boxhead_get_var_by_type <- function(data, type) {
 
-  data %>%
-    dt_boxhead_get() %>%
-    dplyr::filter(type == !!type) %>%
+  dplyr::filter(dt_boxhead_get(data = data), type == !!type) %>%
     magrittr::extract2("var")
 }
 
 dt_boxhead_get_vars_labels_default <- function(data) {
 
+  unlist(
+    subset(dt_boxhead_get(data = data), type == "default") %>%
+      magrittr::extract2("column_label")
+  )
+}
+
+dt_boxhead_get_alignment_by_var <- function(data, var) {
+
   data %>%
     dt_boxhead_get() %>%
-    dplyr::filter(type == "default") %>%
-    magrittr::extract2("column_label") %>%
-    unlist()
+    dplyr::filter(var == !!var) %>%
+    magrittr::extract2("column_align")
 }
 
 check_names_dt_boxhead_expr <- function(expr) {
@@ -204,7 +219,7 @@ check_vars_dt_boxhead <- function(var, dt_boxhead) {
 
 dt_boxhead_build <- function(data, context) {
 
-  boxh <- dt_boxhead_get(data)
+  boxh <- dt_boxhead_get(data = data)
 
   boxh$column_label <-
     lapply(boxh$column_label, function(label) process_text(label, context))
@@ -216,7 +231,7 @@ dt_boxhead_build <- function(data, context) {
 
 dt_boxhead_set_var_order <- function(data, vars) {
 
-  boxh <- dt_boxhead_get(data)
+  boxh <- dt_boxhead_get(data = data)
 
   if (length(vars) != nrow(boxh) ||
       length(unique(vars)) != nrow(boxh) ||
