@@ -29,9 +29,7 @@ dt_options_set_value <- function(data, option, value) {
 
 dt_options_get_value <- function(data, option) {
 
-  dt_options <-
-    data %>%
-    dt_options_get()
+  dt_options <- dt_options_get(data = data)
 
   dt_options$value[[which(dt_options$parameter == option)]]
 }
@@ -52,6 +50,7 @@ dt_options_tbl <-
     "container_overflow_x",              FALSE,  "container",        "overflow","auto",
     "container_overflow_y",              FALSE,  "container",        "overflow","auto",
     "table_id",                          FALSE,  "table",            "value",   NA_character_,
+    "table_caption",                     FALSE,  "table",            "value",   NULL,
     "table_width",                        TRUE,  "table",            "px",      "auto",
     "table_layout",                       TRUE,  "table",            "value",   "fixed",
     "table_margin_left",                  TRUE,  "table",            "px",      "auto",
@@ -124,6 +123,7 @@ dt_options_tbl <-
     "row_group_border_left_style",        TRUE,  "row_group",        "value",   "none",
     "row_group_border_left_width",        TRUE,  "row_group",        "px",      "1px",
     "row_group_border_left_color",        TRUE,  "row_group",        "value",   "#D3D3D3",
+    "row_group_default_label",           FALSE,  "row_group",        "value",   NA_character_,
     "table_body_hlines_style",            TRUE,  "table_body",       "value",   "solid",
     "table_body_hlines_width",            TRUE,  "table_body",       "px",      "1px",
     "table_body_hlines_color",            TRUE,  "table_body",       "value",   "#D3D3D3",
