@@ -19,6 +19,8 @@ dt_spanners_init <- function(data) {
     vars = list(),
     # The spanner label
     spanner_label = list(),
+    # The spanner id
+    spanner_id = character(0),
     # Should be columns be gathered under a single spanner label?
     gather = logical(0),
     built = NA_character_
@@ -26,14 +28,19 @@ dt_spanners_init <- function(data) {
     dt_spanners_set(spanners = ., data = data)
 }
 
-dt_spanners_add <- function(data, vars, spanner_label, gather) {
+dt_spanners_add <- function(data,
+                            vars,
+                            spanner_label,
+                            spanner_id,
+                            gather) {
 
-  data %>%
-    dt_spanners_get() %>%
+
+  dt_spanners_get(data = data) %>%
     dplyr::bind_rows(
       dplyr::tibble(
         vars = list(vars),
         spanner_label = list(spanner_label),
+        spanner_id = as.character(spanner_id),
         gather = gather,
         built = NA_character_
       )
@@ -50,19 +57,30 @@ dt_spanners_exists <- function(data) {
 
 dt_spanners_build <- function(data, context) {
 
-  spanners <- dt_spanners_get(data)
+  spanners <- dt_spanners_get(data = data)
 
   spanners$built <-
-    vapply(spanners$spanner_label, function(label) process_text(label, context), character(1))
+    vapply(
+      spanners$spanner_label,
+      FUN.VALUE = character(1),
+      FUN = function(label) process_text(label, context)
+    )
 
   data <- dt_spanners_set(data = data, spanners = spanners)
 
   data
 }
 
-dt_spanners_print <- function(data, include_hidden = TRUE) {
+dt_spanners_get_ids <- function(data) {
 
-  spanners <- data %>% dt_spanners_get()
+  spanners <- dt_spanners_get(data = data)
+
+  spanners$spanner_id
+}
+
+dt_spanners_print <- function(data, include_hidden = TRUE, ids = FALSE) {
+
+  spanners <- dt_spanners_get(data = data)
 
   if (!include_hidden) {
     vars <- dt_boxhead_get_vars_default(data = data)
@@ -73,8 +91,13 @@ dt_spanners_print <- function(data, include_hidden = TRUE) {
   vars_list <- rep(NA_character_, length(vars)) %>% magrittr::set_names(vars)
 
   for (i in seq_len(nrow(spanners))) {
-    vars_list[spanners$vars[[i]]] <- spanners$built[[i]]
+
+    if (ids) {
+      vars_list[spanners$vars[[i]]] <- spanners$spanner_id[i]
+    } else {
+      vars_list[spanners$vars[[i]]] <- spanners$built[[i]]
+    }
   }
 
-  vars_list[names(vars_list) %in% vars] %>% unname()
+  unname(vars_list[names(vars_list) %in% vars])
 }
