@@ -9,7 +9,7 @@ test_that("the `cols_move()` function works correctly", {
   # `cyl`, and `drat` columns placed after `drat`
   tbl_latex <-
     gt(data = mtcars_short) %>%
-    cols_move(columns = vars(mpg, cyl, disp), after = vars(drat))
+    cols_move(columns = c(mpg, cyl, disp), after = drat)
 
   # Expect a characteristic pattern
   grepl(
@@ -37,7 +37,7 @@ test_that("the `cols_move()` function works correctly", {
   # `cyl`, and `drat` columns placed after `carb` (the end of the series)
   tbl_latex <-
     gt(data = mtcars_short) %>%
-    cols_move(columns = vars(mpg, cyl, disp), after = vars(carb))
+    cols_move(columns = c(mpg, cyl, disp), after = carb)
 
   # Expect a characteristic pattern
   grepl(
@@ -54,7 +54,7 @@ test_that("the `cols_move_to_start()` function works correctly", {
   # and `carb` columns placed at the start
   tbl_latex <-
     gt(data = mtcars_short) %>%
-    cols_move_to_start(columns = vars(gear, carb))
+    cols_move_to_start(columns = c(gear, carb))
 
   # Expect a characteristic pattern
   grepl(
@@ -85,7 +85,7 @@ test_that("the `cols_move_to_end()` function works correctly", {
   # and `carb` columns placed at the end
   tbl_latex <-
     gt(data = mtcars_short) %>%
-    cols_move_to_end(columns = vars(gear, carb))
+    cols_move_to_end(columns = c(gear, carb))
 
   # Expect a characteristic pattern
   grepl(
