@@ -9,19 +9,18 @@ data <-
   cols_hide(columns = "mpg") %>%
   cols_hide(columns = "vs") %>%
   tab_row_group(
-    group = "Mercs",
+    label = "Mercs",
     rows = contains("Merc"),
   ) %>%
   tab_row_group(
-    group = "Mazdas",
+    label = "Mazdas",
     rows = contains("Mazda"),
   ) %>%
-  tab_row_group(
-    others = "Others"
-  ) %>%
+  tab_options(row_group.default_label = "Others") %>%
   tab_spanner(
     label = "gear_carb_cyl",
-    columns = vars(gear, carb, cyl)
+    id = "gcc",
+    columns = c(gear, carb, cyl)
   ) %>%
   row_group_order(groups = c("Mazdas", "Mercs")) %>%
   cols_merge_range(
@@ -35,13 +34,13 @@ data <-
   tab_source_note(source_note = "this is a source note") %>%
   summary_rows(
     groups = c("Mazdas", "Mercs"),
-    columns = vars(hp, wt, qsec),
+    columns = c(hp, wt, qsec),
     fns = list(
       ~mean(., na.rm = TRUE),
       ~sum(., na.rm = TRUE))
   ) %>%
   summary_rows(
-    columns = vars(hp, wt),
+    columns = c(hp, wt),
     fns = list(
       ~mean(., na.rm = TRUE),
       ~sum(., na.rm = TRUE))
@@ -57,23 +56,31 @@ data_2 <-
   dplyr::ungroup() %>%
   dplyr::select(mfr, model, drivetrain, msrp) %>%
   gt() %>%
-  tab_spanner(label = "make and model", columns = vars(mfr, model)) %>%
-  tab_spanner(label = "specs and pricing", columns = vars(drivetrain, msrp)) %>%
+  tab_spanner(
+    label = "make and model",
+    id = "mm",
+    columns = c(mfr, model)
+  ) %>%
+  tab_spanner(
+    label = "specs and pricing",
+    id = "sp",
+    columns = c(drivetrain, msrp)
+  ) %>%
   tab_footnote(
     footnote = "Prices in USD.",
-    locations = cells_column_labels(columns = vars(msrp))
+    locations = cells_column_labels(columns = msrp)
   ) %>%
   tab_footnote(
     footnote = "AWD = All Wheel Drive, RWD = Rear Wheel Drive.",
-    locations = cells_column_labels(columns = vars(drivetrain))
+    locations = cells_column_labels(columns = drivetrain)
   ) %>%
   tab_footnote(
     footnote = "The most important details.",
-    locations = cells_column_spanners(spanners = "specs and pricing")
+    locations = cells_column_spanners(spanners = "sp")
   ) %>%
   tab_footnote(
     footnote = "German cars only.",
-    locations = cells_column_spanners(spanners = "make and model")
+    locations = cells_column_spanners(spanners = "mm")
   )
 
 # Create a table from `gtcars` that has footnotes
@@ -88,13 +95,13 @@ data_3 <-
   gt(rowname_col = "model", groupname_col = "mfr") %>%
   summary_rows(
     groups = c("BMW", "Audi"),
-    columns = vars(msrp),
+    columns = "msrp",
     fns = list(
       ~mean(., na.rm = TRUE),
       ~min(., na.rm = TRUE))
   ) %>%
   summary_rows(
-    columns = vars(msrp),
+    columns = "msrp",
     fns = list(
       ~min(., na.rm = TRUE),
       ~max(., na.rm = TRUE))
@@ -103,19 +110,19 @@ data_3 <-
     footnote = "Average price for BMW and Audi.",
     locations = cells_summary(
       groups = c("BMW", "Audi"),
-      columns = vars(msrp),
+      columns = "msrp",
       rows = starts_with("me"))
   ) %>%
   tab_footnote(
     footnote = "Maximum price across all cars.",
     locations = cells_grand_summary(
-      columns = vars(msrp),
+      columns = "msrp",
       rows = starts_with("ma"))
   ) %>%
   tab_footnote(
     footnote = "Minimum price across all cars.",
     locations = cells_grand_summary(
-      columns = vars(msrp),
+      columns = "msrp",
       rows = starts_with("mi"))
   )
 
@@ -183,7 +190,7 @@ test_that("the `tab_footnote()` function works correctly", {
     tab_footnote(
       footnote = "Column labels and stub footnote.",
       locations = list(
-        cells_column_labels(columns = TRUE),
+        cells_column_labels(),
         cells_stub(rows = TRUE)
       )
     )
@@ -351,7 +358,7 @@ test_that("the `tab_footnote()` function works correctly", {
     tab_footnote(
       footnote = "Grand summary cell footnote.",
       locations = cells_grand_summary(
-        columns = vars(wt), rows = starts_with("s")
+        columns = wt, rows = starts_with("s")
       )
     )
 
@@ -404,7 +411,7 @@ test_that("the `tab_footnote()` function works correctly", {
     tab_footnote(
       footnote = "Grand summary cell footnote.",
       locations = cells_grand_summary(
-        columns = vars(wt), rows = starts_with("s")
+        columns = wt, rows = starts_with("s")
       )
     )
 
@@ -453,7 +460,7 @@ test_that("the `tab_footnote()` function works correctly", {
     data %>%
     tab_footnote(
       footnote = "Column group footnote.",
-      locations = cells_column_spanners(spanners = "gear_carb_cyl")
+      locations = cells_column_spanners(spanners = "gcc")
     )
 
   # Expect that the internal `footnotes_df` data frame will have
@@ -468,7 +475,7 @@ test_that("the `tab_footnote()` function works correctly", {
     unlist() %>%
     unname() %>%
     expect_equal(
-      c("columns_groups", "gear_carb_cyl", NA_character_, "3", NA_character_,
+      c("columns_groups", "gcc", NA_character_, "3", NA_character_,
         NA_character_, "Column group footnote.")
     )
 
@@ -540,13 +547,13 @@ test_that("the `tab_footnote()` function works correctly", {
         footnote = "Footnote error.",
         locations = cells_body(columns = "disp", rows = "Mazda RX7")))
 
-  # Apply a footnote to a single data cell; this time, use `vars()`
+  # Apply a footnote to a single data cell; this time, use `c()`
   # to specify the `rows`
   tab <-
     data %>%
     tab_footnote(
       footnote = "A footnote.",
-      locations = cells_body(columns = "disp", rows = vars(`Mazda RX4`)))
+      locations = cells_body(columns = "disp", rows = c("Mazda RX4")))
 
   # Expect that the internal `footnotes_df` data frame will have
   # a single row
@@ -562,13 +569,13 @@ test_that("the `tab_footnote()` function works correctly", {
     expect_equal(
     c("data", NA_character_, "disp", "5", "1", NA_character_, "A footnote."))
 
-  # Apply a footnote to a single data cell; this time, use `vars()`
+  # Apply a footnote to a single data cell; this time, use `c()`
   # to specify the `columns`
   tab <-
     data %>%
     tab_footnote(
       footnote = "A footnote.",
-      locations = cells_body(columns = vars(disp, hp), rows = "Mazda RX4"))
+      locations = cells_body(columns = c(disp, hp), rows = "Mazda RX4"))
 
   # Expect that the internal `footnotes_df` data frame will have two rows
   dt_footnotes_get(data = tab) %>%
@@ -728,13 +735,13 @@ test_that("the `list_of_summaries` table is structured correctly", {
     gt(rowname_col = "model", groupname_col = "mfr") %>%
     summary_rows(
       groups = c("BMW", "Audi"),
-      columns = vars(msrp),
+      columns = msrp,
       fns = list(
         ~mean(., na.rm = TRUE),
         ~min(., na.rm = TRUE))
     ) %>%
     summary_rows(
-      columns = vars(msrp),
+      columns = msrp,
       fns = list(
         ~min(., na.rm = TRUE),
         ~max(., na.rm = TRUE))
